@@ -155,23 +155,32 @@ register_setting(
 )
 
 register_setting(
-    name="MOBILE_USER_AGENTS",
-    description=_("Strings to search user agent for when testing for a "
-        "mobile device."),
+    name="DEFAULT_DEVICE",
+    description=_("Device specific template sub-directory to use as the "
+        "default device."),
+    editable=False, 
+    default="",
+)
+
+register_setting(
+    name="DEVICE_USER_AGENTS",
+    description=_("Mapping of device specific template sub-directory names to "
+        "the sequence of strings that may be found in their user agents."),
     editable=False, 
     default=(
-        "2.0 MMP", "240x320", "400X240", "AvantGo", "BlackBerry", 
-        "Blazer", "Cellphone", "Danger", "DoCoMo", "Elaine/3.0",
-        "EudoraWeb", "Googlebot-Mobile", "hiptop", "IEMobile", 
-        "KYOCERA/WX310K", "LG/U990", "MIDP-2.", "MMEF20", "MOT-V", 
-        "NetFront", "Newt", "Nintendo Wii", "Nitro", "Nokia", 
-        "Opera Mini", "Palm", "PlayStation Portable", "portalmmm",
-        "Proxinet", "ProxiNet", "SHARP-TQ-GX10", "SHG-i900", 
-        "Small", "SonyEricsson", "Symbian OS", "SymbianOS", 
-        "TS21i-10", "UP.Browser", "UP.Link", "webOS", "Windows CE", 
-        "WinWAP", "YahooSeeker/M1A1-R2D2", "iPhone", "iPod", "Android", 
-        "BlackBerry9530", "LG-TU915 Obigo", "LGE VX", "webOS", 
-        "Nokia5800",
+        ("mobile", ("2.0 MMP", "240x320", "400X240", "AvantGo", "BlackBerry", 
+            "Blazer", "Cellphone", "Danger", "DoCoMo", "Elaine/3.0",
+            "EudoraWeb", "Googlebot-Mobile", "hiptop", "IEMobile", 
+            "KYOCERA/WX310K", "LG/U990", "MIDP-2.", "MMEF20", "MOT-V", 
+            "NetFront", "Newt", "Nintendo Wii", "Nitro", "Nokia", 
+            "Opera Mini", "Palm", "PlayStation Portable", "portalmmm",
+            "Proxinet", "ProxiNet", "SHARP-TQ-GX10", "SHG-i900", 
+            "Small", "SonyEricsson", "Symbian OS", "SymbianOS", 
+            "TS21i-10", "UP.Browser", "UP.Link", "webOS", "Windows CE", 
+            "WinWAP", "YahooSeeker/M1A1-R2D2", "iPhone", "iPod", "Android", 
+            "BlackBerry9530", "LG-TU915 Obigo", "LGE VX", "webOS", 
+            "Nokia5800",)
+        ),
     ),
 )
 
@@ -182,6 +191,13 @@ register_setting(
     default=4,
 )
 
+register_setting(
+    name="THEME", 
+    description=_("Package name of theme app to use."),
+    editable=False, 
+    default="",
+)
+
 register_setting(
     name="PAGES_MENU_SHOW_ALL", 
     description=_("If ``True``, the pages menu will show all levels of "
