@@ -9,7 +9,6 @@ from django.utils.translation import ugettext, ugettext_lazy as _
 
 from mezzanine.core.fields import HtmlField
 from mezzanine.core.managers import DisplayableManager, KeywordManager
-from mezzanine.settings import CONTENT_STATUS_CHOICES, CONTENT_STATUS_DRAFT
 from mezzanine.utils import base_concrete_model
 
 
@@ -59,6 +58,14 @@ class Slugged(models.Model):
     def get_slug(self):
         return slugify(self.title)
 
+
+CONTENT_STATUS_DRAFT = 1
+CONTENT_STATUS_PUBLISHED = 2
+CONTENT_STATUS_CHOICES = (
+    (CONTENT_STATUS_DRAFT, _("Draft")),
+    (CONTENT_STATUS_PUBLISHED, _("Published")),
+)
+
 class Displayable(Slugged):
     """
     Abstract model that provides features of a visible page on the website
@@ -161,7 +168,6 @@ class OrderableBase(ModelBase):
 
     def __new__(cls, name, bases, attrs):
         if "Meta" not in attrs:
-
             class Meta:
                 pass
             attrs["Meta"] = Meta
@@ -248,6 +254,5 @@ class Keyword(Slugged):
     objects = KeywordManager()
 
     class Meta:
-        verbose_name = "Keyword"
-        verbose_name_plural = "Keywords"
-
+        verbose_name = _("Keyword")
+        verbose_name_plural = _("Keywords")
