@@ -2,9 +2,9 @@
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
+from mezzanine.conf import settings
 from mezzanine.core.fields import HtmlField
 from mezzanine.core.models import Orderable, Content
-from mezzanine.forms.settings import FIELD_MAX_LENGTH, LABEL_MAX_LENGTH
 from mezzanine.pages.models import Page
 
 
@@ -63,15 +63,17 @@ class Field(Orderable):
     """
 
     form = models.ForeignKey("Form", related_name="fields")
-    label = models.CharField(_("Label"), max_length=LABEL_MAX_LENGTH)
+    label = models.CharField(_("Label"), 
+        max_length=settings.FORMS_LABEL_MAX_LENGTH)
     field_type = models.CharField(_("Type"), choices=FIELD_CHOICES,
         max_length=55)
     required = models.BooleanField(_("Required"), default=True)
     visible = models.BooleanField(_("Visible"), default=True)
     choices = models.CharField(_("Choices"), max_length=1000, blank=True,
-        help_text="Comma separated options where applicable")
+        help_text=_("Comma separated options where applicable. If an option "
+            "itself contains commas, surround the option with `backticks`."))
     default = models.CharField(_("Default value"), blank=True, 
-        max_length=FIELD_MAX_LENGTH)
+        max_length=settings.FORMS_FIELD_MAX_LENGTH)
     help_text = models.CharField(_("Help text"), blank=True, max_length=100)
 
     objects = FieldManager()
@@ -84,6 +86,30 @@ class Field(Orderable):
     def __unicode__(self):
         return self.label
 
+    def get_choices(self):
+        """
+        Parse a comma separated choice string into a list of choices taking
+        into account quoted choices.
+        """
+        choice = ""
+        (quote, unquote) = ("`", "`")
+        quoted = False
+        for char in self.choices:
+            if not quoted and char == quote:
+                quoted = True
+            elif quoted and char == unquote:
+                quoted = False
+            elif char == "," and not quoted:
+                choice = choice.strip()
+                if choice:
+                    yield choice, choice
+                choice = ""
+            else:
+                choice += char
+        choice = choice.strip()
+        if choice:
+            yield choice, choice
+
 
 class FormEntry(models.Model):
     """
@@ -105,7 +131,7 @@ class FieldEntry(models.Model):
 
     entry = models.ForeignKey("FormEntry", related_name="fields")
     field_id = models.IntegerField()
-    value = models.CharField(max_length=FIELD_MAX_LENGTH)
+    value = models.CharField(max_length=settings.FORMS_FIELD_MAX_LENGTH)
 
     class Meta:
         verbose_name = _("Form field entry")
