@@ -11,8 +11,8 @@ if project_dir == "project_template":
     dev_path = os.path.abspath(os.path.join(project_path, "..", ".."))
     if dev_path not in sys.path:
         sys.path.insert(0, dev_path)
-    import mezzanine
-    mezzanine_path = os.path.dirname(os.path.abspath(mezzanine.__file__))
+    from mezzanine.utils import path_for_import
+    mezzanine_path = path_for_import("mezzanine")
     assert os.path.abspath(os.path.join(mezzanine_path, "..")) == dev_path
 
 from django.core.management import execute_manager
